import { Data } from 'effect';
import type { Union } from 'ts-toolbelt';
import type { Instance } from './get-instances/instance';
import type { Specifier } from './specifier';
export declare namespace Report {
    export namespace Semver {
        type Any = Union.Strict<Report.Semver.Invalid.Any | Report.Semver.Valid.Any>;
        namespace Valid {
            type Any = Union.Strict<Report.Disabled | Report.FilteredOut | Report.Ignored | Report.Valid>;
        }
        namespace Invalid {
            type Any = Union.Strict<Report.Semver.Fixable.Any | Report.Semver.Unfixable.Any>;
        }
        namespace Fixable {
            type Any = Report.SemverRangeMismatch;
        }
        namespace Unfixable {
            type Any = Report.UnsupportedMismatch;
        }
    }
    export namespace Version {
        interface Group {
            name: string;
            reports: Report.Version.Any[];
        }
        type Any = Union.Strict<Report.Version.Invalid.Any | Report.Version.Valid.Any>;
        namespace Valid {
            type Any = Union.Strict<Report.Disabled | Report.FilteredOut | Report.Ignored | Report.Valid>;
        }
        namespace Invalid {
            type Any = Union.Strict<Report.Version.Fixable.Any | Report.Version.Unfixable.Any>;
        }
        namespace Fixable {
            type Any = Union.Strict<Report.Banned | Report.HighestSemverMismatch | Report.LocalPackageMismatch | Report.LowestSemverMismatch | Report.PinnedMismatch | Report.SemverRangeMismatch | Report.SnappedToMismatch>;
        }
        namespace Unfixable {
            type Any = Union.Strict<Report.MissingLocalVersion | Report.MissingSnappedToMismatch | Report.UnsupportedMismatch | Report.SameRangeMismatch>;
        }
    }
    const Disabled_base: new <A extends Record<string, any> = {}>(args: import("effect/Types").Equals<Omit<A, keyof import("effect/Equal").Equal>, {}> extends true ? void : { readonly [P in keyof A as P extends "_tag" | keyof import("effect/Equal").Equal ? never : P]: A[P]; }) => Data.Data<Readonly<A> & {
        readonly _tag: "Disabled";
    }>;
    /** Semver Groups are disabled by default */
    export class Disabled extends Disabled_base<{
        readonly instance: Instance;
    }> {
    }
    const FilteredOut_base: new <A extends Record<string, any> = {}>(args: import("effect/Types").Equals<Omit<A, keyof import("effect/Equal").Equal>, {}> extends true ? void : { readonly [P in keyof A as P extends "_tag" | keyof import("effect/Equal").Equal ? never : P]: A[P]; }) => Data.Data<Readonly<A> & {
        readonly _tag: "FilteredOut";
    }>;
    /** Has a name which does not match the `--filter` RegExp */
    export class FilteredOut extends FilteredOut_base<{
        readonly instance: Instance;
    }> {
    }
    const Ignored_base: new <A extends Record<string, any> = {}>(args: import("effect/Types").Equals<Omit<A, keyof import("effect/Equal").Equal>, {}> extends true ? void : { readonly [P in keyof A as P extends "_tag" | keyof import("effect/Equal").Equal ? never : P]: A[P]; }) => Data.Data<Readonly<A> & {
        readonly _tag: "Ignored";
    }>;
    /** Is in an ignored version group */
    export class Ignored extends Ignored_base<{
        readonly instance: Instance;
    }> {
    }
    const Valid_base: new <A extends Record<string, any> = {}>(args: import("effect/Types").Equals<Omit<A, keyof import("effect/Equal").Equal>, {}> extends true ? void : { readonly [P in keyof A as P extends "_tag" | keyof import("effect/Equal").Equal ? never : P]: A[P]; }) => Data.Data<Readonly<A> & {
        readonly _tag: "Valid";
    }>;
    /** Version satisfies the rules of its version group */
    export class Valid extends Valid_base<{
        readonly specifier: Specifier.Any;
    }> {
    }
    const Banned_base: new <A extends Record<string, any> = {}>(args: import("effect/Types").Equals<Omit<A, keyof import("effect/Equal").Equal>, {}> extends true ? void : { readonly [P in keyof A as P extends "_tag" | keyof import("effect/Equal").Equal ? never : P]: A[P]; }) => Data.Data<Readonly<A> & {
        readonly _tag: "Banned";
    }>;
    /** Must be removed */
    export class Banned extends Banned_base<{
        readonly fixable: Specifier.Any;
    }> {
    }
    const HighestSemverMismatch_base: new <A extends Record<string, any> = {}>(args: import("effect/Types").Equals<Omit<A, keyof import("effect/Equal").Equal>, {}> extends true ? void : { readonly [P in keyof A as P extends "_tag" | keyof import("effect/Equal").Equal ? never : P]: A[P]; }) => Data.Data<Readonly<A> & {
        readonly _tag: "HighestSemverMismatch";
    }>;
    /** Version mismatches and should use a higher version found on another */
    export class HighestSemverMismatch extends HighestSemverMismatch_base<{
        readonly fixable: Specifier.Any;
    }> {
    }
    const LocalPackageMismatch_base: new <A extends Record<string, any> = {}>(args: import("effect/Types").Equals<Omit<A, keyof import("effect/Equal").Equal>, {}> extends true ? void : { readonly [P in keyof A as P extends "_tag" | keyof import("effect/Equal").Equal ? never : P]: A[P]; }) => Data.Data<Readonly<A> & {
        readonly _tag: "LocalPackageMismatch";
    }>;
    /** Version mismatches the `.version` of the package developed in this repo */
    export class LocalPackageMismatch extends LocalPackageMismatch_base<{
        readonly fixable: Specifier.Any;
        readonly localInstance: Instance;
    }> {
    }
    const LowestSemverMismatch_base: new <A extends Record<string, any> = {}>(args: import("effect/Types").Equals<Omit<A, keyof import("effect/Equal").Equal>, {}> extends true ? void : { readonly [P in keyof A as P extends "_tag" | keyof import("effect/Equal").Equal ? never : P]: A[P]; }) => Data.Data<Readonly<A> & {
        readonly _tag: "LowestSemverMismatch";
    }>;
    /** Version mismatches and should use a lower version found on another */
    export class LowestSemverMismatch extends LowestSemverMismatch_base<{
        readonly fixable: Specifier.Any;
    }> {
    }
    const PinnedMismatch_base: new <A extends Record<string, any> = {}>(args: import("effect/Types").Equals<Omit<A, keyof import("effect/Equal").Equal>, {}> extends true ? void : { readonly [P in keyof A as P extends "_tag" | keyof import("effect/Equal").Equal ? never : P]: A[P]; }) => Data.Data<Readonly<A> & {
        readonly _tag: "PinnedMismatch";
    }>;
    /** Version is not identical to the `pinVersion` of its Pinned version group */
    export class PinnedMismatch extends PinnedMismatch_base<{
        readonly fixable: Specifier.Any;
    }> {
    }
    const SemverRangeMismatch_base: new <A extends Record<string, any> = {}>(args: import("effect/Types").Equals<Omit<A, keyof import("effect/Equal").Equal>, {}> extends true ? void : { readonly [P in keyof A as P extends "_tag" | keyof import("effect/Equal").Equal ? never : P]: A[P]; }) => Data.Data<Readonly<A> & {
        readonly _tag: "SemverRangeMismatch";
    }>;
    /** Version is identical but the semver range does not match its semver group */
    export class SemverRangeMismatch extends SemverRangeMismatch_base<{
        readonly fixable: Specifier.Any;
    }> {
    }
    const SnappedToMismatch_base: new <A extends Record<string, any> = {}>(args: import("effect/Types").Equals<Omit<A, keyof import("effect/Equal").Equal>, {}> extends true ? void : { readonly [P in keyof A as P extends "_tag" | keyof import("effect/Equal").Equal ? never : P]: A[P]; }) => Data.Data<Readonly<A> & {
        readonly _tag: "SnappedToMismatch";
    }>;
    /** Version mismatches the version used by the packages in the `snapTo` array */
    export class SnappedToMismatch extends SnappedToMismatch_base<{
        readonly fixable: Specifier.Any;
        readonly localInstance: Instance;
    }> {
    }
    const MissingLocalVersion_base: new <A extends Record<string, any> = {}>(args: import("effect/Types").Equals<Omit<A, keyof import("effect/Equal").Equal>, {}> extends true ? void : { readonly [P in keyof A as P extends "_tag" | keyof import("effect/Equal").Equal ? never : P]: A[P]; }) => Data.Data<Readonly<A> & {
        readonly _tag: "MissingLocalVersion";
    }>;
    /** Dependency should match a local package.json which is missing a .version */
    export class MissingLocalVersion extends MissingLocalVersion_base<{
        readonly localInstance: Instance;
        readonly unfixable: Instance;
    }> {
    }
    const MissingSnappedToMismatch_base: new <A extends Record<string, any> = {}>(args: import("effect/Types").Equals<Omit<A, keyof import("effect/Equal").Equal>, {}> extends true ? void : { readonly [P in keyof A as P extends "_tag" | keyof import("effect/Equal").Equal ? never : P]: A[P]; }) => Data.Data<Readonly<A> & {
        readonly _tag: "MissingSnappedToMismatch";
    }>;
    /** Dependency is not present in any of the packages in the `snapTo` array */
    export class MissingSnappedToMismatch extends MissingSnappedToMismatch_base<{
        readonly unfixable: Instance;
    }> {
    }
    const SameRangeMismatch_base: new <A extends Record<string, any> = {}>(args: import("effect/Types").Equals<Omit<A, keyof import("effect/Equal").Equal>, {}> extends true ? void : { readonly [P in keyof A as P extends "_tag" | keyof import("effect/Equal").Equal ? never : P]: A[P]; }) => Data.Data<Readonly<A> & {
        readonly _tag: "SameRangeMismatch";
    }>;
    /** Specifier does not cover the specifiers of every other instance in this group */
    export class SameRangeMismatch extends SameRangeMismatch_base<{
        readonly unfixable: Instance;
        /** the raw specifiers which this instance's specifier did not cover */
        readonly mismatches: string[];
    }> {
    }
    const UnsupportedMismatch_base: new <A extends Record<string, any> = {}>(args: import("effect/Types").Equals<Omit<A, keyof import("effect/Equal").Equal>, {}> extends true ? void : { readonly [P in keyof A as P extends "_tag" | keyof import("effect/Equal").Equal ? never : P]: A[P]; }) => Data.Data<Readonly<A> & {
        readonly _tag: "UnsupportedMismatch";
    }>;
    /** Version mismatches and is not semver, syncpack cannot guess what to do */
    export class UnsupportedMismatch extends UnsupportedMismatch_base<{
        readonly unfixable: Instance;
    }> {
    }
    export {};
}
